@@ -119,7 +119,8 @@ generate_propagation_context(sentry_value_t propagation_context)
 }
 
 static void
-set_dynamic_sampling_context(sentry_options_t *options, sentry_scope_t *scope)
+set_dynamic_sampling_context(
+    const sentry_options_t *options, sentry_scope_t *scope)
 {
     sentry_value_decref(scope->dynamic_sampling_context);
     // add the Dynamic Sampling Context to the `trace` header
@@ -191,8 +192,7 @@ sentry_init(sentry_options_t *options)
         SENTRY_DEBUG("falling back to non-absolute database path");
         options->database_path = database_path;
     }
-    SENTRY_INFOF("using database path \"%" SENTRY_PATH_PRI "\"",
-        options->database_path->path);
+    SENTRY_INFOF("using database path \"%s\"", options->database_path->path);
 
     // try to create and lock our run folder as early as possibly, since it is
     // fallible. since it does locking, it will not interfere with run folder
@@ -555,7 +555,7 @@ sentry__capture_event(sentry_value_t event, sentry_scope_t *local_scope)
         if (envelope) {
             // Accept a racy read here, since SENTRY_WITH_OPTIONS only prevents
             // the options from being deallocated while we use them, but no lock
-            // is active and session could change during session shutdown.
+            // is active and the session could change during session shutdown.
             // We recheck below inside the lock and don't pay for a lock here.
             // This also means we accept a missed window of opportunity if an
             // event is being sent concurrently to session initialization, which
@@ -569,7 +569,7 @@ sentry__capture_event(sentry_value_t event, sentry_scope_t *local_scope)
                 if (mut_options->session) {
                     sentry__envelope_add_session(
                         envelope, mut_options->session);
-                    // we're assuming that if a session is added to an envelope
+                    // we're assuming that if a session is added to an envelope,
                     // it will be sent onwards.  This means we now need to set
                     // the init flag to false because we're no longer in the
                     // initial session update.
@@ -1573,8 +1573,7 @@ sentry_capture_minidump_n(const char *path, size_t path_len)
         return sentry_uuid_nil();
     }
 
-    SENTRY_DEBUGF(
-        "Capturing minidump \"%" SENTRY_PATH_PRI "\"", dump_path->path);
+    SENTRY_DEBUGF("Capturing minidump \"%s\"", dump_path->path);
 
     SENTRY_WITH_OPTIONS (options) {
         sentry_uuid_t event_id;
@@ -1587,7 +1586,7 @@ sentry_capture_minidump_n(const char *path, size_t path_len)
         if (!envelope || sentry_uuid_is_nil(&event_id)) {
             sentry_value_decref(event);
         } else {
-            // the minidump is added as an attachment, with type
+            // the minidump is added as an attachment, with the type
             // `event.minidump`
             sentry_envelope_item_t *item = sentry__envelope_add_from_path(
                 envelope, dump_path, "attachment");
@@ -1599,18 +1598,12 @@ sentry_capture_minidump_n(const char *path, size_t path_len)
                     sentry_value_new_string("event.minidump"));
 
                 sentry__envelope_item_set_header(item, "filename",
-#ifdef SENTRY_PLATFORM_WINDOWS
-                    sentry__value_new_string_from_wstr(
-#else
-                    sentry_value_new_string(
-#endif
-                        sentry__path_filename(dump_path)));
+                    sentry_value_new_string(sentry__path_filename(dump_path)));
 
                 sentry__capture_envelope(options->transport, envelope);
 
-                SENTRY_INFOF("Minidump has been captured: \"%" SENTRY_PATH_PRI
-                             "\"",
-                    dump_path->path);
+                SENTRY_INFOF(
+                    "Minidump has been captured: \"%s\"", dump_path->path);
                 sentry__path_free(dump_path);
 
                 sentry_options_free((sentry_options_t *)options);
@@ -1619,8 +1612,7 @@ sentry_capture_minidump_n(const char *path, size_t path_len)
         }
     }
 
-    SENTRY_WARNF(
-        "Minidump was not captured: \"%" SENTRY_PATH_PRI "\"", dump_path->path);
+    SENTRY_WARNF("Minidump was not captured: \"%s\"", dump_path->path);
     sentry__path_free(dump_path);
 
     return sentry_uuid_nil();
